@@ -19,8 +19,12 @@ mod common;
 #[cfg(test)]
 mod supported {
 
-    use crate::common::{remote_context, standalone_context};
+    use crate::common::{
+        remote_context, remote_context_with_state, standalone_context,
+        standalone_context_with_state,
+    };
     use ballista_core::config::BallistaConfig;
+    use datafusion::physical_plan::collect;
     use datafusion::prelude::*;
     use datafusion::{assert_batches_eq, prelude::SessionContext};
     use rstest::*;
@@ -66,6 +70,122 @@ mod supported {
 
         Ok(())
     }
+
+    // tests if client will collect statistics for
+    // collect/show operation
+    #[rstest]
+    #[case::standalone(standalone_context())]
+    #[case::remote(remote_context())]
+    #[tokio::test]
+    async fn should_collect_client_statistics_for_show(
+        #[future(awt)]
+        #[case]
+        ctx: SessionContext,
+        test_data: String,
+    ) -> datafusion::error::Result<()> {
+        ctx.register_parquet(
+            "test",
+            &format!("{test_data}/alltypes_plain.parquet"),
+            Default::default(),
+        )
+        .await?;
+
+        let plan = ctx
+            .sql("select string_col, timestamp_col from test where id > 4")
+            .await?
+            .create_physical_plan()
+            .await?;
+
+        let result = collect(plan.clone(), ctx.task_ctx()).await?;
+
+        let expected = [
+            "+------------+---------------------+",
+            "| string_col | timestamp_col       |",
+            "+------------+---------------------+",
+            "| 31         | 2009-03-01T00:01:00 |",
+            "| 30         | 2009-04-01T00:00:00 |",
+            "| 31         | 2009-04-01T00:01:00 |",
+            "+------------+---------------------+",
+        ];
+
+        assert_batches_eq!(expected, &result);
+
+        let metrics = plan.metrics().unwrap();
+        let rows = metrics.output_rows().unwrap();
+
+        assert_eq!(3, rows);
+        assert!(
+            plan.metrics()
+                .unwrap()
+                .sum_by_name("transferred_bytes")
+                .unwrap()
+                .as_usize()
+                > 0
+        );
+
+        Ok(())
+    }
+
+    // tests if client will collect statistics for
+    // insert operation
+    #[rstest]
+    #[case::standalone(standalone_context())]
+    #[case::remote(remote_context())]
+    #[tokio::test]
+    #[cfg(not(windows))] // test is failing at windows, can't debug it
+    async fn should_collect_client_statistics_for_insert(
+        #[future(awt)]
+        #[case]
+        ctx: SessionContext,
+        test_data: String,
+    ) -> datafusion::error::Result<()> {
+        ctx.register_parquet(
+            "test",
+            &format!("{test_data}/alltypes_plain.parquet"),
+            Default::default(),
+        )
+        .await
+        .unwrap();
+        let write_dir = tempfile::tempdir().expect("temporary directory to be created");
+        let write_dir_path = write_dir
+            .path()
+            .to_str()
+            .expect("path to be converted to str");
+
+        ctx.sql(&format!("CREATE EXTERNAL TABLE written_table (id INTEGER, string_col STRING, timestamp_col BIGINT) STORED AS PARQUET LOCATION '{}'" , write_dir_path)).await.unwrap().show().await.unwrap();
+
+        let plan = ctx
+            .sql("INSERT INTO written_table select  id, string_col, timestamp_col from test")
+            .await?
+            .create_physical_plan()
+            .await?;
+
+        let result = collect(plan.clone(), ctx.task_ctx()).await.unwrap();
+
+        // INSERT operation should return only single row
+        assert_eq!(1, plan.metrics().unwrap().output_rows().unwrap());
+        assert!(
+            plan.metrics()
+                .unwrap()
+                .sum_by_name("transferred_bytes")
+                .unwrap()
+                .as_usize()
+                > 0
+        );
+
+        let expected = [
+            "+-------+",
+            "| count |",
+            "+-------+",
+            "| 8     |",
+            "+-------+",
+        ];
+
+        assert_batches_eq!(expected, &result);
+
+        Ok(())
+    }
+
     #[rstest]
     #[case::standalone(standalone_context())]
     #[case::remote(remote_context())]
@@ -399,7 +519,7 @@ mod supported {
     }
 
     // tests if `ctx.enable_url_table()` works correctly
-    // it did not work before datafusion 45.0.0
+    // it did not work before datafusion 46.0.0
     #[rstest]
     #[case::standalone(standalone_context())]
     #[case::remote(remote_context())]
@@ -434,4 +554,199 @@ mod supported {
 
         Ok(())
     }
+
+    // export RUST_MIN_STACK=20971520
+    #[rstest]
+    #[case::standalone(standalone_context())]
+    #[case::remote(remote_context())]
+    #[tokio::test]
+    #[cfg(not(windows))] // test is failing at windows, can't debug it
+    async fn should_support_sql_insert_into(
+        #[future(awt)]
+        #[case]
+        ctx: SessionContext,
+        test_data: String,
+    ) {
+        ctx.register_parquet(
+            "test",
+            &format!("{test_data}/alltypes_plain.parquet"),
+            Default::default(),
+        )
+        .await
+        .unwrap();
+        let write_dir = tempfile::tempdir().expect("temporary directory to be created");
+        let write_dir_path = write_dir
+            .path()
+            .to_str()
+            .expect("path to be converted to str");
+
+        ctx.sql(&format!("CREATE EXTERNAL TABLE written_table (id INTEGER, string_col STRING, timestamp_col BIGINT) STORED AS PARQUET LOCATION '{}'" , write_dir_path)).await.unwrap().show().await.unwrap();
+
+        let _ = ctx
+            .sql("INSERT INTO written_table select  id, string_col, timestamp_col from test")
+            .await
+            .unwrap()
+            .collect()
+            .await
+            .unwrap();
+
+        ctx.deregister_table("written_table")
+            .expect("table to be dropped");
+
+        ctx.register_parquet("written_table_test", write_dir_path, Default::default())
+            .await
+            .unwrap();
+
+        let result = ctx
+            .sql("select id, string_col, timestamp_col from written_table_test where id > 4 order by id")
+            .await.unwrap()
+            .collect()
+            .await.unwrap();
+
+        let expected = [
+            "+----+------------+---------------------+",
+            "| id | string_col | timestamp_col       |",
+            "+----+------------+---------------------+",
+            "| 5  | 1          | 1235865660000000000 |",
+            "| 6  | 0          | 1238544000000000000 |",
+            "| 7  | 1          | 1238544060000000000 |",
+            "+----+------------+---------------------+",
+        ];
+
+        assert_batches_eq!(expected, &result);
+    }
+
+    #[rstest]
+    #[case::standalone(standalone_context())]
+    #[case::remote(remote_context())]
+    #[case::standalone_state(standalone_context_with_state())]
+    #[case::remote_state(remote_context_with_state())]
+    #[tokio::test]
+    #[cfg(not(windows))] // test is failing at windows, can't debug it
+    async fn should_execute_sql_write_read_roundtrip(
+        #[future(awt)]
+        #[case]
+        ctx: SessionContext,
+        test_data: String,
+    ) -> datafusion::error::Result<()> {
+        ctx.register_parquet(
+            "test",
+            &format!("{test_data}/alltypes_plain.parquet"),
+            Default::default(),
+        )
+        .await?;
+
+        let expected = [
+            "+----+------------+",
+            "| id | string_col |",
+            "+----+------------+",
+            "| 5  | 31         |",
+            "| 6  | 30         |",
+            "| 7  | 31         |",
+            "+----+------------+",
+        ];
+
+        let write_dir = tempfile::tempdir().expect("temporary directory to be created");
+        let write_dir_path = write_dir
+            .path()
+            .to_str()
+            .expect("path to be converted to str");
+
+        ctx.sql("select * from test")
+            .await?
+            .write_parquet(write_dir_path, Default::default(), Default::default())
+            .await?;
+
+        ctx.register_parquet("p_written_table", write_dir_path, Default::default())
+            .await?;
+
+        let result = ctx
+            .sql("select id, string_col from p_written_table where id > 4")
+            .await?
+            .collect()
+            .await?;
+
+        assert_batches_eq!(expected, &result);
+
+        ctx.sql("select * from test")
+            .await?
+            .write_csv(write_dir_path, Default::default(), Default::default())
+            .await?;
+
+        ctx.register_csv("c_written_table", write_dir_path, Default::default())
+            .await?;
+
+        let result = ctx
+            .sql("select id, string_col from c_written_table where id > 4")
+            .await?
+            .collect()
+            .await?;
+
+        assert_batches_eq!(expected, &result);
+
+        //
+        // TODO: enable when json supports lands in datafusion 47
+        //
+        // ctx.sql("select * from test")
+        //     .await?
+        //     .write_json(write_dir_path, Default::default(), Default::default())
+        //     .await?;
+
+        // ctx.register_json("j_written_table", write_dir_path, Default::default())
+        //     .await?;
+
+        // let result = ctx
+        //     .sql("select id, string_col from j_written_table where id > 4")
+        //     .await?
+        //     .collect()
+        //     .await?;
+
+        // assert_batches_eq!(expected, &result);
+
+        Ok(())
+    }
+
+    #[rstest]
+    #[case::standalone(standalone_context())]
+    #[case::remote(remote_context())]
+    #[case::standalone_state(standalone_context_with_state())]
+    #[case::remote_state(remote_context_with_state())]
+    #[tokio::test]
+    async fn should_execute_sql_show_multiple_times(
+        #[future(awt)]
+        #[case]
+        ctx: SessionContext,
+        test_data: String,
+    ) -> datafusion::error::Result<()> {
+        ctx.register_parquet(
+            "test",
+            &format!("{test_data}/alltypes_plain.parquet"),
+            Default::default(),
+        )
+        .await?;
+
+        let expected = [
+            "+------------+---------------------+",
+            "| string_col | timestamp_col       |",
+            "+------------+---------------------+",
+            "| 31         | 2009-03-01T00:01:00 |",
+            "| 30         | 2009-04-01T00:00:00 |",
+            "| 31         | 2009-04-01T00:01:00 |",
+            "+------------+---------------------+",
+        ];
+        // there were cases when we break session context
+        // with standalone setup. so subsequent query for the
+        // same table fails with table does not exist
+        for _ in 0..5 {
+            let result = ctx
+                .sql("select string_col, timestamp_col from test where id > 4")
+                .await?
+                .collect()
+                .await?;
+
+            assert_batches_eq!(expected, &result);
+        }
+
+        Ok(())
+    }
 }
