@@ -22,9 +22,9 @@ use ballista_core::execution_plans::{
     ShuffleReaderExec, ShuffleWriterExec, UnresolvedShuffleExec,
 };
 use datafusion::datasource::listing::PartitionedFile;
-use datafusion::datasource::physical_plan::{
-    AvroExec, CsvExec, FileScanConfig, NdJsonExec, ParquetExec,
-};
+use datafusion::datasource::memory::MemorySourceConfig;
+use datafusion::datasource::physical_plan::FileScanConfig;
+use datafusion::datasource::source::DataSourceExec;
 use datafusion::physical_plan::aggregates::AggregateExec;
 use datafusion::physical_plan::coalesce_batches::CoalesceBatchesExec;
 use datafusion::physical_plan::coalesce_partitions::CoalescePartitionsExec;
@@ -32,7 +32,6 @@ use datafusion::physical_plan::filter::FilterExec;
 use datafusion::physical_plan::joins::CrossJoinExec;
 use datafusion::physical_plan::joins::HashJoinExec;
 use datafusion::physical_plan::limit::{GlobalLimitExec, LocalLimitExec};
-use datafusion::physical_plan::memory::MemoryExec;
 use datafusion::physical_plan::projection::ProjectionExec;
 use datafusion::physical_plan::repartition::RepartitionExec;
 use datafusion::physical_plan::sorts::sort::SortExec;
@@ -320,32 +319,24 @@ filter_expr={}",
             "ShuffleWriter [{} partitions]",
             exec.input_partition_count()
         )
-    } else if plan.as_any().downcast_ref::<MemoryExec>().is_some() {
-        "MemoryExec".to_string()
-    } else if let Some(exec) = plan.as_any().downcast_ref::<CsvExec>() {
+    } else if let Some(exec) = plan.as_any().downcast_ref::<DataSourceExec>() {
+        let config = if let Some(config) =
+            exec.data_source().as_any().downcast_ref::<FileScanConfig>()
+        {
+            get_file_scan(config)
+        } else if let Some(_config) = exec
+            .data_source()
+            .as_any()
+            .downcast_ref::<MemorySourceConfig>()
+        {
+            "Memory".to_string()
+        } else {
+            "Unknown".to_string()
+        };
+
         let parts = exec.properties().output_partitioning().partition_count();
-        format!(
-            "CSV: {} [{} partitions]",
-            get_file_scan(exec.base_config()),
-            parts
-        )
-    } else if let Some(exec) = plan.as_any().downcast_ref::<NdJsonExec>() {
-        let parts = exec.properties().output_partitioning().partition_count();
-        format!("JSON [{parts} partitions]")
-    } else if let Some(exec) = plan.as_any().downcast_ref::<AvroExec>() {
-        let parts = exec.properties().output_partitioning().partition_count();
-        format!(
-            "Avro: {} [{} partitions]",
-            get_file_scan(exec.base_config()),
-            parts
-        )
-    } else if let Some(exec) = plan.as_any().downcast_ref::<ParquetExec>() {
-        let parts = exec.properties().output_partitioning().partition_count();
-        format!(
-            "Parquet: {} [{} partitions]",
-            get_file_scan(exec.base_config()),
-            parts
-        )
+
+        format!("DataSourceExec: ({}) [{} partitions]", config, parts)
     } else if let Some(exec) = plan.as_any().downcast_ref::<GlobalLimitExec>() {
         format!(
             "GlobalLimit(skip={}, fetch={:?})",
@@ -415,6 +406,7 @@ fn get_file_scan(scan: &FileScanConfig) -> String {
 
 #[cfg(test)]
 mod tests {
+    use crate::planner::DefaultDistributedPlanner;
     use crate::state::execution_graph::ExecutionGraph;
     use crate::state::execution_graph_dot::ExecutionGraphDot;
     use ballista_core::error::{BallistaError, Result};
@@ -434,13 +426,13 @@ mod tests {
 	subgraph cluster0 {
 		label = "Stage 1 [Resolved]";
 		stage_1_0 [shape=box, label="ShuffleWriter [2 partitions]"]
-		stage_1_0_0 [shape=box, label="MemoryExec"]
+		stage_1_0_0 [shape=box, label="DataSourceExec: (Memory) [2 partitions]"]
 		stage_1_0_0 -> stage_1_0
 	}
 	subgraph cluster1 {
 		label = "Stage 2 [Resolved]";
 		stage_2_0 [shape=box, label="ShuffleWriter [2 partitions]"]
-		stage_2_0_0 [shape=box, label="MemoryExec"]
+		stage_2_0_0 [shape=box, label="DataSourceExec: (Memory) [2 partitions]"]
 		stage_2_0_0 -> stage_2_0
 	}
 	subgraph cluster2 {
@@ -464,7 +456,7 @@ filter_expr="]
 	subgraph cluster3 {
 		label = "Stage 4 [Resolved]";
 		stage_4_0 [shape=box, label="ShuffleWriter [2 partitions]"]
-		stage_4_0_0 [shape=box, label="MemoryExec"]
+		stage_4_0_0 [shape=box, label="DataSourceExec: (Memory) [2 partitions]"]
 		stage_4_0_0 -> stage_4_0
 	}
 	subgraph cluster4 {
@@ -533,19 +525,19 @@ filter_expr="]
 	subgraph cluster0 {
 		label = "Stage 1 [Resolved]";
 		stage_1_0 [shape=box, label="ShuffleWriter [2 partitions]"]
-		stage_1_0_0 [shape=box, label="MemoryExec"]
+		stage_1_0_0 [shape=box, label="DataSourceExec: (Memory) [2 partitions]"]
 		stage_1_0_0 -> stage_1_0
 	}
 	subgraph cluster1 {
 		label = "Stage 2 [Resolved]";
 		stage_2_0 [shape=box, label="ShuffleWriter [2 partitions]"]
-		stage_2_0_0 [shape=box, label="MemoryExec"]
+		stage_2_0_0 [shape=box, label="DataSourceExec: (Memory) [2 partitions]"]
 		stage_2_0_0 -> stage_2_0
 	}
 	subgraph cluster2 {
 		label = "Stage 3 [Resolved]";
 		stage_3_0 [shape=box, label="ShuffleWriter [2 partitions]"]
-		stage_3_0_0 [shape=box, label="MemoryExec"]
+		stage_3_0_0 [shape=box, label="DataSourceExec: (Memory) [2 partitions]"]
 		stage_3_0_0 -> stage_3_0
 	}
 	subgraph cluster3 {
@@ -645,6 +637,7 @@ filter_expr="]
             .await?;
         let plan = df.into_optimized_plan()?;
         let plan = ctx.state().create_physical_plan(&plan).await?;
+        let mut planner = DefaultDistributedPlanner::new();
         ExecutionGraph::new(
             "scheduler_id",
             "job_id",
@@ -653,6 +646,7 @@ filter_expr="]
             plan,
             0,
             Arc::new(SessionConfig::new_with_ballista()),
+            &mut planner,
         )
     }
 
@@ -679,6 +673,7 @@ filter_expr="]
             .await?;
         let plan = df.into_optimized_plan()?;
         let plan = ctx.state().create_physical_plan(&plan).await?;
+        let mut planner = DefaultDistributedPlanner::new();
         ExecutionGraph::new(
             "scheduler_id",
             "job_id",
@@ -687,6 +682,7 @@ filter_expr="]
             plan,
             0,
             Arc::new(SessionConfig::new_with_ballista()),
+            &mut planner,
         )
     }
 }
