@@ -49,6 +49,7 @@ use prost::Message;
 
 pub mod execution_graph;
 pub mod execution_graph_dot;
+pub mod execution_stage;
 pub mod executor_manager;
 pub mod session_manager;
 pub mod task_manager;
@@ -166,7 +167,7 @@ impl<T: 'static + AsLogicalPlan, U: 'static + AsExecutionPlan> SchedulerState<T,
             .bind_schedulable_tasks(self.task_manager.get_running_job_cache())
             .await?;
         if schedulable_tasks.is_empty() {
-            warn!("No schedulable tasks found to be launched");
+            debug!("No schedulable tasks found to be launched");
             return Ok(());
         }
 
